@@ -50,7 +50,7 @@ get_premium_export <- function(cookie, what="ACTIVITIES", start_date="2015-01-13
   if(response$status_code!=200){
     stop("problem with request, this may be available only for premium subscribers")
   }
-  file_id <- as(response, "character")
+  file_id <- methods::as(response, "character")
   file_id <- RJSONIO::fromJSON(file_id, asText=TRUE)
   file_id <- file_id["fileIdentifier"]
 
@@ -78,7 +78,7 @@ get_premium_export <- function(cookie, what="ACTIVITIES", start_date="2015-01-13
 
   a <- httr::GET(paste0("https://www.fitbit.com/premium/export/download/",
                       file_id))
-  df <- read.csv(text=as(a, "character"), skip=1, stringsAsFactors=F)
+  df <- utils::read.csv(text=methods::as(a, "character"), skip=1, stringsAsFactors=F)
 
   return(df)
 }
